// $Id$

/***************************************************************************
*   Copyright (C) 2004 by Thomas Fischer                                  *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXFILE_H
#define BIBTEXFILE_H

#include <qobject.h>
#include <qvaluelist.h>

class QString;
class QChar;
class QStringList;

class BibTeXElement;
class BibTeXEntry;
class BibTeXString;

/**
@author Thomas Fischer
*/
class BibTeXFile : public QObject
{
    Q_OBJECT
public:
    enum StringProtection { spNone, spParanthesis, spQuote, spBoth };
    // valid token
    enum Token {tComment, tPreamble, tBraketOpen, tBraketClose, tAlphaNumText, tComma, tAssign, tString, tStrConcat, tUnknown, tEOF, tEntry};

    BibTeXFile( QObject *parent = 0, const char *name = 0 );
    ~BibTeXFile();

    // load a local BibTeX file
    bool load( const QString &url );
    bool load( QTextStream& stream );
    // save to a local BibTeX file
    bool save( const QString &url );

    unsigned int count ();
    BibTeXElement* at( const unsigned int index );
    void appendElement( BibTeXElement *element );
    void deleteElement( BibTeXElement *element );

signals:
    void parseError( int errorId );
    void progress( int current, int total );

public slots:
    void cancelOperation();

protected:
    typedef QValueList<BibTeXElement*> ElementList;
    ElementList elements;

private:
    QString tokenBuffer;
    QChar tokenChar;
    bool cancelOp;

    Token readToken( QTextStream &stream );
    QString readChars( QTextStream &stream );
    BibTeXString* readString( QTextStream &stream );
    BibTeXEntry* readEntry( QString &entryType, QTextStream &stream );
    void clearElements();
};

#endif
