// $Id$

/***************************************************************************
*   Copyright (C) 2004 by Thomas Fischer                                  *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <qlistview.h>
#include <klocale.h>

#include "kbibtexlistviewitem.h"
#include "bibtexelement.h"
#include "bibtexentry.h"
#include "bibtexcomment.h"
#include "bibtexpreamble.h"
#include "bibtexstring.h"

KBibTeXListViewItem::KBibTeXListViewItem( BibTeXElement *element, QListView *parent ) : KListViewItem( parent, parent->lastItem() ), m_element( element )
{
    setTexts();
}

KBibTeXListViewItem::KBibTeXListViewItem( BibTeXElement *element, QListView *parent, QListViewItem *after ) : KListViewItem( parent, after ), m_element( element )
{
    setTexts();
}

KBibTeXListViewItem::~KBibTeXListViewItem()
{}

BibTeXElement* KBibTeXListViewItem::element()
{
    return m_element;
}

void KBibTeXListViewItem::updateItem()
{
    setTexts();
}

void KBibTeXListViewItem::setTexts()
{
    setText( 0, BibTeXElement::elementTypeToString( m_element->elementType() ) );

    BibTeXEntry *entry;
    entry = dynamic_cast<BibTeXEntry*>( m_element );
    if ( entry )
    {
        BibTeXEntry::Field * field = NULL;
        QString text;
        setText( 1, entry->id() );
        field = entry->field( BibTeXEntry::ftTitle );
        if ( field != NULL )
            setText( 2, field->value );
        field = entry->field( BibTeXEntry::ftAuthor );
        if ( ( field != NULL ) && !field->value.isEmpty() )
            setText( 3, field->value );
        else
        {
            field = entry->field( BibTeXEntry::ftEditor );
            if ( ( field != NULL ) && !field->value.isEmpty() )
                setText( 3, field->value );
        }
        field = entry->field( BibTeXEntry::ftYear );
        if ( field != NULL )
            setText( 4, field->value );
    }
    else
    {
        BibTeXComment *comment;
        comment = dynamic_cast<BibTeXComment*>( m_element );
        if ( comment )
        {
            setText( 2, comment->comment() );
        }
        else
        {
            BibTeXPreamble *preamble;
            preamble = dynamic_cast<BibTeXPreamble*>( m_element );
            if ( preamble )
            {
                setText( 2, preamble->preamble() );
            }
            else
            {
                BibTeXString *string;
                string = dynamic_cast<BibTeXString*>( m_element );
                if ( string )
                {
                    setText( 1, string->id() );
                    setText( 2, string->value() );
                }
            }
        }
    }
}
