/***************************************************************************
*   Copyright (C) 2004 by Thomas Fischer                                  *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#include <qlabel.h>
#include <qlistview.h>
#include <kdialogbase.h>
#include <klocale.h>

#include <bibtexfile.h>
#include <bibtexstring.h>
#include "kbibtexselectstring.h"

KBibTeXSelectString::KBibTeXSelectString( BibTeXFile * bibTeXFile, QWidget *parent, const char *name )
        : QVBox( parent, name )
{
    setSpacing( KDialog::spacingHint() );
    setMinimumWidth( 384 );

    label = new QLabel( i18n( "Select &macro:" ), this );
    lv = new QListView( this );

    lv->addColumn( i18n( "Name" ) );
    lv->addColumn( i18n( "Value" ) );
    lv ->setAllColumnsShowFocus(true);
    label->setBuddy( lv );

    for ( unsigned int i = 0; i < bibTeXFile->count(); i++ )
    {
        BibTeXString* string = dynamic_cast<BibTeXString*>( bibTeXFile->at( i ) );
        if ( string )
        {
            new QListViewItem( lv, string->id(), string->value() );
        }
    }
}


KBibTeXSelectString::~KBibTeXSelectString()
{}

QString KBibTeXSelectString::execute( BibTeXFile * bibTeXFile, QWidget *parent, const char *name )
{
    QString result = QString::null;

    KDialogBase * dlg = new KDialogBase( parent, name, true, i18n( "Select Macro" ), KDialogBase::Ok | KDialogBase::Cancel );
    KBibTeXSelectString *ss = new KBibTeXSelectString( bibTeXFile, dlg, name );
    dlg->setMainWidget( ss );

    if ( ( dlg->exec() == QDialog::Accepted ) && ( ss->lv->currentItem() ) )
        result = ss->lv->currentItem() ->text( 0 );

    delete ss;
    delete dlg;

    return result;
}

#include "kbibtexselectstring.moc"
